cumulusci.tasks.salesforce package
==================================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.salesforce.tests

Submodules
----------


.. automodule:: cumulusci.tasks.salesforce.BaseRetrieveMetadata
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceApiTask
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceMetadataApiTask
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceTask
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.BaseUninstallMetadata
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.CreateCommunity
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.CreatePackage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.Deploy
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.DeployBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.EnsureRecordTypes
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.GetInstalledPackages
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.InstallPackageVersion
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.ListCommunities
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.ListCommunityTemplates
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.PublishCommunity
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.RetrievePackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.RetrieveReportsAndDashboards
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.RetrieveUnpackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.SOQLQuery
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallLocal
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallLocalBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallLocalNamespacedBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallPackage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallPackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UninstallPackagedIncremental
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UpdateAdminProfile
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.UpdateDependencies
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.activate_flow
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.custom_settings
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.org_settings
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.package_upload
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.sourcetracking
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.trigger_handlers
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.salesforce
   :members:
   :undoc-members:
   :show-inheritance:
